@@ -10,19 +10,22 @@ class DriverAPI(object):
     @property
     def url(self):
         raise NotImplementedError
-        
+
     def visit(self, url):
         raise NotImplementedError
 
+    def switch_to_frame(self, id):
+        raise NotImplementedError
+
     def execute_script(self, script):
         raise NotImplementedError
-        
+
     def evaluate_script(self, script):
         raise NotImplementedError
 
     def find_by_css_selector(self, css_selector):
         raise NotImplementedError
-        
+
     def find_by_xpath(self, xpath):
         raise NotImplementedError
 
@@ -41,6 +44,9 @@ class DriverAPI(object):
     def find_link_by_text(self, text):
         raise NotImplementedError
 
+    def wait_for_element(self, selector, timeout, interval):
+        raise NotImplementedError
+
     def fill_in(self, name, value):
         raise NotImplementedError
 
@@ -49,7 +55,7 @@ class DriverAPI(object):
 
     def choose(self, name):
         raise NotImplementedError
-    
+
     def check(self, name):
         raise NotImplementedError
 
@@ -72,17 +78,20 @@ class ElementAPI(object):
 
     def click(self):
         raise NotImplementedError
-        
+
     def check(self):
         raise NotImplementedError
-        
+
     def uncheck(self):
         raise NotImplementedError
 
+    def mouseover(self):
+        raise NotImplementedError
+
     @property
     def checked(self):
         raise NotImplementedError
-        
+
     @property
     def visible(self):
         raise NotImplementedError
