@@ -9,7 +9,38 @@ EXAMPLE_HTML = """\
 <html>
   <head>
     <title>Example Title</title>
-    <script type="text/javascript" src="http://ajax.googleapis.com/ajax/libs/jquery/1.4/jquery.min.js"></script> 
+    <script type="text/javascript" src="/static/jquery.min.js"></script>
+    <script type="text/javascript">
+        $(document).ready(function() {
+           $(".add-async-element").click(function() {
+                setTimeout(function() {
+                    $('body').append('<h4 id="async-header" class="async-element">async elment</h4>');
+                    $('body').append('<input type="text" name="async-input" class="async-input" />');
+                }, 1200 );
+                setTimeout(function() {
+                    $('body').append('<h5 id="async-header2" class="async-element2">async elment2</h5>');
+                    $('body').append('<input type="text" name="async-input2" class="async-input2" />');
+                }, 2400 );
+           });
+
+           $(".remove-async-element").click(function() {
+                setTimeout(function() {
+                    $('.async-element').remove();
+                    $('.async-input').remove();
+                }, 1200 );
+           });
+
+           $(".add-element-mouseover").mouseover(function () {
+                $('body').append('<label for="what-is-your-name" class="over-label">What is your name?</label>');
+                $('body').append('<input type="text" id="what-is-your-name" class="over-input" name="whatsname" />');
+           });
+
+           $(".add-element-mouseover").mouseout(function () {
+                $('.over-label').remove();
+                $('.over-input').remove();
+           });
+        });
+    </script>
   </head>
   <body>
     <h1 id="firstheader">Example Header</h1>
@@ -39,6 +70,20 @@ EXAMPLE_HTML = """\
     <div id="visible">visible</div>
     <div id="invisible" style="display:none">invisible</div>
     <a href="/foo">FOO</a>
+    <a class='add-async-element' href="#">add async element</a>
+    <a class='remove-async-element' href="#">remove async element</a>
+    <a class='add-element-mouseover' href="#">addelement (mouseover)</a>
+    <iframe id="iframemodal" src="/iframe"></iframe>
+  </body>
+</html>"""
+
+EXAMPLE_IFRAME_HTML = """\
+<html>
+  <head>
+    <title>Example Title</title>
+  </head>
+  <body>
+    <h1 id="firstheader">IFrame Example Header</h1>
   </body>
 </html>"""
 
@@ -48,6 +93,10 @@ app = Flask(__name__)
 def index():
     return EXAMPLE_HTML
 
+@app.route('/iframe')
+def iframed():
+    return EXAMPLE_IFRAME_HTML
+
 @app.route('/name', methods=['GET'])
 def get_name():
     return "My name is: Master Splinter"
@@ -65,7 +114,7 @@ def upload_file():
 @app.route('/foo')
 def foo():
     return "BAR!"
-
+    
 class Env(object):
     pass
 
