@@ -1,8 +1,8 @@
 import unittest
-from should_dsl import should
 from splinter.browser import Browser
 from fake_webapp import EXAMPLE_APP
 from base import WebDriverTests
+from nose.tools import raises
 
 class ChromeBrowserTest(WebDriverTests, unittest.TestCase):
 
@@ -17,6 +17,7 @@ class ChromeBrowserTest(WebDriverTests, unittest.TestCase):
     def tearDownClass(cls):
         cls.browser.quit()
 
+    @raises(NotImplementedError)
     def test_attach_file_is_not_implemented(self):
         "attach file is no implemented for chrome driver"
-        (self.browser.attach_file, 'file', 'file_paht') |should| throw(NotImplementedError)
+        self.browser.attach_file('file', 'file_paht')
